@@ -62,6 +62,7 @@ def cmd_ssh(client: RemoteDockerClient, ssh_options=None, ssh_cmd=None):
 def cmd_start(client: RemoteDockerClient):
     """Start the remote agent instance"""
     print(client.start_instance())
+    client.use_remote_context()
 
 
 @cli.command(name="stop")
@@ -69,6 +70,7 @@ def cmd_start(client: RemoteDockerClient):
 def cmd_stop(client: RemoteDockerClient):
     """Stop the remote agent instance"""
     print(client.stop_instance())
+    client.use_default_context()
 
 
 @cli.command(name="ip")
@@ -90,6 +92,7 @@ def cmd_create_keypair(client: RemoteDockerClient):
 def cmd_create(client: RemoteDockerClient):
     """Provision a new ec2 instance to use as the remote agent"""
     print(client.create_instance())
+    client.use_remote_context()
 
 
 @cli.command(name="delete")
@@ -104,6 +107,7 @@ def cmd_delete(client: RemoteDockerClient):
 
     click.confirm("Are you sure you want to delete your instance?", abort=True)
     print(client.delete_instance())
+    client.use_default_context()
 
 
 @cli.command(
@@ -162,3 +166,14 @@ def enable_termination_protection(client: RemoteDockerClient):
     the API and AWS console GUI"
     """
     client.enable_termination_protection()
+
+
+@cli.command(
+    name="context",
+)
+@pass_config
+def use_remote_context(client: RemoteDockerClient):
+    """
+    Creates and switches to the remote-docker context
+    """
+    client.use_remote_context()
